@@ -5,16 +5,13 @@
 #' @inheritParams act_collapse
 #'
 #' @export
-case_labels <- function(log, eventlog = deprecated()) {
+case_labels <- function(log) {
   UseMethod("case_labels")
 }
 
 #' @describeIn case_labels Retrieve case labels from log
 #' @export
-case_labels.log <- function(log, eventlog = deprecated()) {
-
-  log <- lifecycle_warning_eventlog(log, eventlog)
-
+case_labels.log <- function(log) {
   log %>%
     pull(.data[[case_id(log)]]) %>%
     unique()
