@@ -5,7 +5,7 @@
 #' @family Counters
 #' @export
 
-n_resources <- function(log, eventlog = deprecated()) {
+n_resources <- function(log) {
 	UseMethod("n_resources")
 }
 
@@ -13,17 +13,13 @@ n_resources <- function(log, eventlog = deprecated()) {
 #' @describeIn n_resources Count number of resources in log
 #' @export
 
-n_resources.log <- function(log, eventlog = deprecated()) {
-	log <- lifecycle_warning_eventlog(log, eventlog)
-
+n_resources.log <- function(log) {
 	length(unique(log[[resource_id(log)]]))
 }
 
 #' @describeIn n_resources Count number of resources in grouped log
 #' @export
-n_resources.grouped_log <- function(log, eventlog = deprecated()) {
-	log <- lifecycle_warning_eventlog(log, eventlog)
-
+n_resources.grouped_log <- function(log) {
 	log %>%
 		summarize(n_resources = n_distinct(.data[[resource_id(log)]])) %>%
 		return()
