@@ -1,19 +1,17 @@
 #' @title Resources
-#' @description Returns a \code{tibble}  containing a list of all resources in the event log, with there absolute and relative frequency
+#' @description Returns a \code{tibble}  containing a list of all resources in the event log, with their absolute and relative frequency
 #' @inheritParams act_collapse
 #' @seealso \code{\link{resource_id}}, \code{\link{eventlog}}
 #' @export resources
 
-resources <- function(log, eventlog = deprecated()) {
+resources <- function(log) {
 	UseMethod("resources")
 }
 
 #' @describeIn resources Generate resource list for eventlog
 #' @export
 
-resources.eventlog <- function(log, eventlog = deprecated()) {
-
-	log <- lifecycle_warning_eventlog(log, eventlog)
+resources.eventlog <- function(log) {
 
 	absolute_frequency <- NULL
 	relative_frequency <- NULL
@@ -30,17 +28,13 @@ resources.eventlog <- function(log, eventlog = deprecated()) {
 #' @describeIn resources Generate resource list for activitylog
 #' @export
 
-resources.activitylog <- function(log, eventlog = deprecated()) {
-	log <- lifecycle_warning_eventlog(log, eventlog)
-
+resources.activitylog <- function(log) {
 	resources.eventlog(to_eventlog(log))
 }
 #' @describeIn resources Compute activity frequencies
 #' @export
 #'
-resources.grouped_log <- function(log, eventlog = deprecated()) {
-	log <- lifecycle_warning_eventlog(log, eventlog)
-
+resources.grouped_log <- function(log) {
 	apply_grouped_fun(log, resources)
 }
 
