@@ -7,10 +7,7 @@ test_that("test lifecycle_warning_eventlog", {
   load("./testdata/patients.rda")
 
   # Works only on exported functions.
-  expect_warning(result1 <- case_labels(eventlog = patients),
-                 "(eventlog)|(case_labels)|(deprecated)|(bupaR 0.5.0.)|(log)")
   expect_warning(result2 <- case_labels(patients),
                  NA)
-  expect_equal(result1, unique(patients[[case_id(patients)]]))
   expect_equal(result2, unique(patients[[case_id(patients)]]))
 })
